==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/hu/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Fiók</strong> regisztráció',
    '<strong>Change</strong> Password' => 'Jelszó <strong>változtatás</strong>',
    '<strong>Change</strong> your password' => '<strong>Változtasd</strong> meg a jelszavadat',
    '<strong>Join</strong> the network' => '<strong>Csatlakozás</strong> a hálózathoz',
    '<strong>Password</strong> changed!' => '<strong>Jelszavad</strong> megváltozott!',
    '<strong>Password</strong> recovery' => '<strong>Jelszó</strong> visszaállítása',
    '<strong>Password</strong> recovery!' => '<strong>Jelszó</strong> visszaállítás!',
    '<strong>Please</strong> sign in' => '<strong>Jelentkezz be</strong>',
    '<strong>Registration</strong> successful!' => '<strong>Regisztráció</strong> sikeres!',
    '<strong>Sign</strong> up' => '<strong>Regisztráció</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Fiókod</strong> sikeresen létrehozva!',
    'Account' => 'Fiók',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Miután egy munkatársunk aktiválta fiókodat, e-mailben értesítünk téged.',
    'Back' => 'Vissza',
    'Change password' => 'Jelszó változtatás',
    'Confirm' => 'Megerősít',
    'Create Account' => 'Fiók létrehozása',
    'Create account' => 'Fiók létrehozása',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Nincs még fiókod? Csatlakozz a közösséghez az e-mail cimed megadásával.',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Biztonsági okokból meg kell változtatnod a jelszavadat a platform használatához.',
    'Enter security code above' => 'Add meg a fenti biztonsági kódot',
    'Forgot your password?' => 'Elfelejtetted a jelszavadat?',
    'Go to login page' => 'Tovább a bejelentkezéshez',
    'Group' => 'Csoport',
    'Hello {displayName}' => 'Szia {displayName}',
    'Hello {displayName},' => 'Szia {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Ha nem használod fel a linket 24 órán belül, akkor le fog járni.',
    'If you\'re already a member, please login with your username/email and password.' => 'Ha már tag vagy, jelentkezz be felhasználónév vagy e-mail és a jelszó használatával.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Add meg az e-mail címedet. A visszaállítási utasításokat elküldjük számodra.',
    'Log out' => 'Kijelentkezés',
    'Login' => 'Bejelentkezés',
    'New user needs approval' => 'Új felhasználót kell jóváhagyni',
    'Password' => 'jelszó',
    'Password recovery' => 'Jelszó visszaállítása',
    'Password reset' => 'Jelszó visszaállítás',
    'Please check your email and follow the instructions!' => 'Kérjük, ellenőrizd az e-mailedet és kövesd az utasitásokat!',
    'Please click on the link below to view request:' => 'Kérjük, kattints az alábbi linkre a kérelem megtekintéséhez:',
    'Please enter the letters from the image.' => 'Kérjük, írd be a betűket a képről.',
    'Please login with your username/email and password.' => 'Jelentkezz be a felhasználónév vagy e-mail és a jelszó használatával.',
    'Please use the following link within the next day to reset your password.' => 'Kérjük, használd fel másnapig az alábbi linket a jelszavad visszaállításához.',
    'Please wait' => 'Kérjük, várj',
    'Register' => 'Regisztráció',
    'Registration successful' => 'Sikeres regisztráció',
    'Remember me' => 'Emlékezz rám',
    'Reset Password' => 'Jelszó visszaállítás',
    'Reset password' => 'Jelszó visszaállítása',
    'Sign in' => 'Bejelentkezés',
    'To log in with your new account, click the button below.' => 'Ha az új fiókoddal szeretnél bejelentkezni, kattints az alábbi gombra.',
    'User or Password incorrect.' => 'Helytelen a felhasználónév vagy a jelszó.',
    'Username or Email' => 'felhasználónév vagy e-mail',
    'Your email' => 'E-mail címed',
    'Your password' => 'Jelszavad',
    'Your password has been successfully changed!' => 'A jelszavad sikeresen megváltoztatva!',
    'Your password is incorrect!' => 'A jelszavad helytelen!',
    'a new user {displayName} needs approval.' => 'egy új felhasználó {displayName} jóváhagyásra vár.',
    'back to home' => 'Vissza a főoldalra',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/hu/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Fiók</strong> regisztráció',
    '<strong>Change</strong> Password' => 'Jelszó <strong>változtatás</strong>',
    '<strong>Change</strong> your password' => '<strong>Változtasd</strong> meg a jelszavadat',
    '<strong>Join</strong> the network' => '<strong>Csatlakozás</strong> a hálózathoz',
    '<strong>Password</strong> changed!' => '<strong>Jelszavad</strong> megváltozott!',
    '<strong>Password</strong> recovery' => '<strong>Jelszó</strong> visszaállítása',
    '<strong>Password</strong> recovery!' => '<strong>Jelszó</strong> visszaállítás!',
    '<strong>Please</strong> sign in' => '<strong>Jelentkezz be</strong>',
    '<strong>Registration</strong> successful!' => '<strong>Regisztráció</strong> sikeres!',
    '<strong>Sign</strong> up' => '<strong>Regisztráció</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Fiókod</strong> sikeresen létrehozva!',
    'Account' => 'Fiók',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Miután egy munkatársunk aktiválta fiókodat, e-mailben értesítünk téged.',
    'Back' => 'Vissza',
    'Change password' => 'Jelszó változtatás',
    'Confirm' => 'Megerősít',
    'Create Account' => 'Fiók létrehozása',
    'Create account' => 'Fiók létrehozása',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Nincs még fiókod? Csatlakozz a közösséghez az e-mail cimed megadásával.',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Biztonsági okokból meg kell változtatnod a jelszavadat a platform használatához.',
    'Forgot your password?' => 'Elfelejtetted a jelszavadat?',
    'Go to login page' => 'Tovább a bejelentkezéshez',
    'Group' => 'Csoport',
    'Hello {displayName}' => 'Szia {displayName}',
    'Hello {displayName},' => 'Szia {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Ha nem használod fel a linket 24 órán belül, akkor le fog járni.',
    'If you\'re already a member, please login with your username/email and password.' => 'Ha már tag vagy, jelentkezz be felhasználónév vagy e-mail és a jelszó használatával.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Add meg az e-mail címedet. A visszaállítási utasításokat elküldjük számodra.',
    'Log out' => 'Kijelentkezés',
    'Login' => 'Bejelentkezés',
    'New user needs approval' => 'Új felhasználót kell jóváhagyni',
    'Password' => 'jelszó',
    'Password recovery' => 'Jelszó visszaállítása',
    'Password reset' => 'Jelszó visszaállítás',
    'Please click on the link below to view request:' => 'Kérjük, kattints az alábbi linkre a kérelem megtekintéséhez:',
    'Please login with your username/email and password.' => 'Jelentkezz be a felhasználónév vagy e-mail és a jelszó használatával.',
    'Please use the following link within the next day to reset your password.' => 'Kérjük, használd fel másnapig az alábbi linket a jelszavad visszaállításához.',
    'Please wait' => 'Kérjük, várj',
    'Register' => 'Regisztráció',
    'Remember me' => 'Emlékezz rám',
    'Reset Password' => 'Jelszó visszaállítás',
    'Reset password' => 'Jelszó visszaállítása',
    'Sign in' => 'Bejelentkezés',
    'To log in with your new account, click the button below.' => 'Ha az új fiókoddal szeretnél bejelentkezni, kattints az alábbi gombra.',
    'User or Password incorrect.' => 'Helytelen a felhasználónév vagy a jelszó.',
    'Username or Email' => 'felhasználónév vagy e-mail',
    'Your email' => 'E-mail címed',
    'Your password' => 'Jelszavad',
    'Your password has been successfully changed!' => 'A jelszavad sikeresen megváltoztatva!',
    'Your password is incorrect!' => 'A jelszavad helytelen!',
    'a new user {displayName} needs approval.' => 'egy új felhasználó {displayName} jóváhagyásra vár.',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
];
